@@ -127,10 +127,7 @@ pub async fn run(config: CustomConfig) -> CliResult {
         let sql = format!("show full columns from {}", table);
         let r: Vec<Row> = conn.query(&sql)?;
         let default = &STRUCT_HEAD.to_owned();
-        let mut struct_head = config.struct_head.as_ref().unwrap();
-        if struct_head == "" {
-            struct_head = default;
-        }
+        let struct_head = config.struct_head.as_ref().unwrap_or(default);
         let mut table_name = table.to_camel_case();
         table_name = first_char_to_uppercase(table_name).await?;
         let table_comment = table_comment_map.get(table);
